@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Designer of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #ifndef FORMWINDOW_H
 #define FORMWINDOW_H
@@ -36,10 +11,11 @@
 #include <QtGui/qundostack.h>
 #include <QtCore/qhash.h>
 #include <QtCore/qlist.h>
-#include <QtCore/qmap.h>
 #include <QtCore/qset.h>
 #include <QtCore/qpointer.h>
 
+#include <utility>
+
 QT_BEGIN_NAMESPACE
 
 class QDesignerDnDItemInterface;
@@ -340,9 +316,8 @@ private:
 
     QString m_fileName;
 
-    using PaletteAndFill = QPair<QPalette ,bool>;
-    using WidgetPaletteMap = QMap<QWidget*, PaletteAndFill>;
-    WidgetPaletteMap m_palettesBeforeHighlight;
+    using PaletteAndFill = std::pair<QPalette, bool>;
+    QHash<QWidget *, PaletteAndFill> m_palettesBeforeHighlight;
 
     QRubberBand *m_rubberBand = nullptr;
 
